@@ -1,4 +1,4 @@
-// $Id: SubordinateStation.cc 7306 2020-06-28 00:24:42Z flaterco $
+// $Id: SubordinateStation.cc 7638 2022-02-13 15:49:07Z flaterco $
 
 /*  SubordinateStation  Station with offsets.
 
@@ -39,7 +39,8 @@ SubordinateStation::SubordinateStation (const Dstr &name_,
            minCurrentBearing_,
            maxCurrentBearing_,
            metadata),
-  _offsets(offsets) {
+  _offsets(offsets),
+  cacheUnits(Units::zulu) {
 
   // Calculate minimumTimeOffset and maximumTimeOffset.
   minimumTimeOffset = maximumTimeOffset = _offsets.maxTimeAdd();
